@@ -155,7 +155,7 @@ class PiwikTracker(object):
 
 		def _get_client_ip():
 			if 'HTTP_X_FORWARDED_FOR' in meta:
-				return meta['real_ip'].split(",")[0]
+				return meta['HTTP_X_FORWARDED_FOR'].split(",")[0]
 			else:
 				return meta.get('REMOTE_ADDR', None)
 
@@ -239,8 +239,11 @@ class PiwikTracker(object):
 		headers = self.build_request_headers(params)
 		logging.debug("Tracking variables: %s" % params)
 		logging.debug("Tracking headers: %s" % headers)
-		response = requests.post(self.php_url, data=params, headers=headers, **self.requests_arguments)
-		logging.debug("Tracking response: %s" % response)
+		try:
+			response = requests.post(self.php_url, data=params, headers=headers, **self.requests_arguments)
+			logging.debug("Tracking response: %s" % response)
+		except:
+			logging.exception("Tracking request failed")
 
 	def tracking_code(self, **kwargs):
 		return TrackingCodeBuilder(self).render(self._build_parameters(**kwargs))
@@ -267,7 +270,8 @@ class TrackingCodeBuilder(object):
 		self.tracker = tracker
 
 	def _paq_push(self, l):
-		return "_paq.push(%s);" % json.dumps(l)
+		# python3's filter() does not return a list
+		return "_paq.push(%s);" % json.dumps(list(l))
 
 	def _event_tracker(self):
 		if not (self.tracker.event_category and self.tracker.event_action):
